@@ -24,7 +24,11 @@ from .exceptions import (
     FritzServiceError,
 )
 from .soaper import Soaper
-from .utils import get_bool_env
+from .utils import (
+    get_bool_env,
+    get_xml_root,
+    localname
+)
 
 # disable InsecureRequestWarning from urllib3
 # because of skipping certificate verification:
@@ -38,6 +42,7 @@ FRITZ_IP_ADDRESS = "169.254.1.1"
 FRITZ_TCP_PORT = 49000
 FRITZ_TLS_PORT = 49443
 FRITZ_USERNAME = "dslf-config"  # for Fritz!OS < 7.24
+FRITZ_BOXINFO_FILE = "jason_boxinfo.xml"
 FRITZ_IGD_DESC_FILE = "igddesc.xml"
 FRITZ_TR64_DESC_FILE = "tr64desc.xml"
 FRITZ_DESCRIPTIONS = [FRITZ_IGD_DESC_FILE, FRITZ_TR64_DESC_FILE]
@@ -225,6 +230,9 @@ class FritzConnection:
         adapter = requests.adapters.HTTPAdapter(
             pool_connections=pool_connections, pool_maxsize=pool_maxsize)
         session.mount(PROTOCOLS[use_tls], adapter)
+        # cache for updatecheck as @functools.cached_property
+        # needs Python >= 3.8:
+        self._updatecheck = None
         # store as instance attributes for use by library modules
         self.address = address
         self.session = session
@@ -278,6 +286,23 @@ class FritzConnection:
         """
         return self.call_action("DeviceInfo1", "GetInfo")["NewDescription"]
 
+    @property
+    def updatecheck(self):
+        """
+        Dictionary with information about the hard- and software version of
+        the device according to "http://fritz.box/jason_boxinfo.xml".
+        """
+        if self._updatecheck is None:
+            xml_data = get_xml_root(
+                f"{self.address}/{FRITZ_BOXINFO_FILE}",
+                timeout=self.timeout,
+                session=self.session
+            )
+            self._updatecheck = {
+                localname(elem): elem.text for elem in xml_data
+            }
+        return self._updatecheck
+
     @staticmethod
     def normalize_name(name):
         """
@@ -448,16 +473,17 @@ class FritzConnection:
             self.device_manager.modelname,
             self.device_manager.system_info[-1]
         )
-        # retrive the same information from an api call. If the result
-        # is the same, the cache-data can considered as valid.
+        # retrive the same information from the updatecheck property.
+        # If the result is the same, the cache-data can considered as valid.
         try:
-            device_info = self.call_action("DeviceInfo:1", "GetInfo")
+            device_info = self.updatecheck
         except FritzConnectionException:
-            # something went wrong, cache data can not be verified.
+            # something went wrong, cache data can not be verified:
+            # should never happen with a connected device.
             return False
         current_id = (
-            device_info['NewModelName'],
-            device_info['NewSoftwareVersion']
+            device_info['Name'],
+            device_info['Version']
         )
         return cached_id == current_id
 
